@@ -7,7 +7,7 @@ from urllib.parse import urljoin, urlencode
 import json, hashlib, hmac, time
 from datetime import datetime
 import requests
-
+import calendar
 
 class NaPoleonBinanceFutureBot(object):
 
@@ -46,16 +46,20 @@ class NaPoleonBinanceFutureBot(object):
         self.cancel_all_order('TRX/USDT')
 
 
-    def get_balance_low_level(self):
+    def get_balance_low_level(self, request_date):
         BASE_URL = 'https://api.binance.com'
         PATH = '/api/v3/account'
-        timestamp = int(time.time() * 1000)
+        if request_date is None:
+            timestamp = int(time.time() * 1000)
+        else:
+            timestamp = calendar.timegm(request_date.timetuple())
+
         headers = {
             'X-MBX-APIKEY': self.apiKey
         }
         params = {
             'recvWindow': 5000,
-            'timestamp': timestamp
+            'timestamp': timestamp,
         }
         query_string = urllib.parse.urlencode(params)
         params['signature'] = hmac.new(self.secret.encode('utf-8'), query_string.encode('utf-8'),
