@@ -519,9 +519,12 @@ def recompute_all(public_key = None, private_key= None, start_time= None, end_ti
     wh['transfers_usd'] = wh.transfers_au + wh.transfers_bnb * wh.open_bnb_bnc
     wh['dt_floor_h'] = wh.index.map(lambda x: x.floor('H'))
     wh = wh.groupby('dt_floor_h').sum()
-    wh.at[wh.index[0], 'realizedPnl'] = 5000  # qqlq k en mars
-    wh[
-        'net_profit'] = wh.realizedPnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
+
+    initial_pnl = wh.at[wh.index[0], 'realized_pnl']
+    starting_value = 10000
+    wh.at[wh.index[0], 'realized_pnl'] = initial_pnl + starting_value  # qqlq k en mars
+
+    wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
     wh['valuation'] = wh.net_profit + wh.transfers_usd
     wh['valuation'] = wh.valuation.cumsum()
     td = td.join(wh.iloc[:, 4:])
@@ -747,37 +750,32 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     wh['transfers_usd'] = wh.transfers_au + wh.transfers_bnb * wh.open_bnb_bnc
     wh['dt_floor_h'] = wh.index.map(lambda x: x.floor('H'))
     wh = wh.groupby('dt_floor_h').sum()
-    wh.at[wh.index[0], 'realizedPnl'] = 5000  # qqlq k en mars
-    wh[
-        'net_profit'] = wh.realizedPnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
+    wh['pnl'] = wh['realized_pnl']
+    initial_pnl = wh.at[wh.index[0], 'realized_pnl']
+    starting_value = 10000
+    wh.at[wh.index[0], 'realized_pnl'] = initial_pnl + starting_value  # qqlq k en mars
+
+    wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
     wh['valuation'] = wh.net_profit + wh.transfers_usd
     wh['valuation'] = wh.valuation.cumsum()
     td = td.join(wh.iloc[:, 4:])
     td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
     td['amount_traded_usd_btc'] = td.traded_xbt * td.avg_btc_price
 
-    x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'trading_fees_eth_usd',
-            'funding_fees_eth_usd', 'open_eth_cc', 'open_eth_bnc',
-            'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'trading_fees_xbt_usd',
-            'funding_fees_xbt_usd', 'open_btc_cc', 'open_btc_bnc',
-            'valuation',
-            'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
-            'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
-            'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-            'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']]
+    x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
+            'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
+            'valuation', 'pnl',
+            'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+            'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
 
     x = x.rename_axis('timestamp')
     x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth',
                  'open_eth_cc', 'open_eth_exchange',
                  'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc',
                  'open_btc_cc', 'open_btc_exchange',
-                 'wallet_amount_usd',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']
+                 'wallet_amount_usd', 'pnl',
+                 'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                 'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
 
     x = x.fillna(0).round(decimals=5)
 
